# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/me/me/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {

        "psr-4": {
            ... ,
            "Me\\Me\\": "packages/me/me/src",
            "Me\\Me\\Seeders\\": "packages/me/me/database/seeders"
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Me\Me\Providers\MeServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Me'  => Me\Me\Facades\Me::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Me\\Me\\Seeders\\MeTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Me\Me\Providers\MeServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Me\Me\Providers\MeServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Me\Me\Providers\MeServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/me/{modulename}

**User**

    http://path-to-route-folder/user/me/{modulename}

**Public**

    http://path-to-route-folder/mes


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/me/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/me/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/me/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/me/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/me/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/me/{modulename}/{slug}
    METHOD: GET